/*
 * CDDL HEADER START
 *
 * The contents of this file are subject to the terms of the
 * Common Development and Distribution License, Version 1.0 only
 * (the "License").  You may not use this file except in compliance
 * with the License.
 *
 * You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE
 * or http://www.opensolaris.org/os/licensing.
 * See the License for the specific language governing permissions
 * and limitations under the License.
 *
 * When distributing Covered Code, include this CDDL HEADER in each
 * file and include the License file at usr/src/OPENSOLARIS.LICENSE.
 * If applicable, add the following below this CDDL HEADER, with the
 * fields enclosed by brackets "[]" replaced with your own identifying
 * information: Portions Copyright [yyyy] [name of copyright owner]
 *
 * CDDL HEADER END
 */

package uk.co.petertribble.jproc.server;

import org.apache.xmlrpc.server.PropertyHandlerMapping;
import org.apache.xmlrpc.server.XmlRpcServer;
import org.apache.xmlrpc.server.XmlRpcServerConfigImpl;
import org.apache.xmlrpc.webserver.WebServer;
import java.io.File;

/**
 * A simple jproc server using the xml-rpc WebServer class. Taken straight
 * from the Apache XML-RPC examples.
 *
 * @author Peter Tribble
 */
public class PServer1 {

    /**
     * Constructs a PServer1 object.
     *
     * @param port a String representing the port to listen on
     */
    public PServer1(int port) {
	this(new PServerConfig(port));
    }

    /**
     * Constructs a PServer1 object.
     *
     * @param ksc  The configuration to be applied
     */
    public PServer1(PServerConfig ksc) {
	try {
	    WebServer webServer = new WebServer(ksc.getPort());
	    XmlRpcServer xmlRpcServer = webServer.getXmlRpcServer();
	    PropertyHandlerMapping phm = new PropertyHandlerMapping();
	    phm.load(Thread.currentThread().getContextClassLoader(),
                   "properties/PServer1.properties");
	    xmlRpcServer.setHandlerMapping(phm);
	    XmlRpcServerConfigImpl serverConfig =
		(XmlRpcServerConfigImpl) xmlRpcServer.getConfig();
	    serverConfig.setContentLengthOptional(false);

	    webServer.start();
	} catch (Exception e) {
	    System.err.println("Server failed to start!");
	}
    }

    private static void usage() {
	System.err.println("Usage: server [-p port | -f config_file]");
	System.exit(1);
    }

    /**
     * Start the server. A -p argument specifies a listener port, or
     * a -f argument specifies a configuration file. Without arguments,
     * listens on port 8080.
     *
     * @param args command line arguments
     */
    public static void main(String[] args) {
	if (args.length == 0) {
	    new PServer1(8080);
	} else if (args.length == 2) {
	    if (args[0].equals("-p")) {
		try {
		    new PServer1(new PServerConfig(Integer.parseInt(args[1])));
		} catch (NumberFormatException nfe) {
		    usage();
		}
	    } else if (args[0].equals("-f")) {
		File f = new File(args[1]);
		if (f.exists()) {
		    new PServer1(new PServerConfig(f));
		} else {
		    usage();
		}
	    } else {
		usage();
	    }
	} else {
	    usage();
	}
    }
}
